@@ -1,6 +1,6 @@
 import logging
 
-from winnowing.impl.winnowing import compare_files as winnowing_compare_files
+from .winnowing.impl.winnowing import compare_files as winnowing_compare_files
 
 logger = logging.getLogger(__name__)
 
